==> jc-1.4.0.tar.gz: gnu/regexp/RETokenLookAhead.h <==
// final class gnu.regexp.RETokenLookAhead

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class ee8e5ce64b7367ac gnu_regexp_RETokenLookAhead
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenLookAhead_H_
#define _JC_gnu_regexp_RETokenLookAhead_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_gnu_regexp_REToken$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenLookAhead$sub_refs	_jc_gnu_regexp_RETokenLookAhead$sub_refs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$sub_nonrefs	_jc_gnu_regexp_RETokenLookAhead$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$refs	_jc_gnu_regexp_RETokenLookAhead$refs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$nonrefs	_jc_gnu_regexp_RETokenLookAhead$nonrefs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$object	_jc_gnu_regexp_RETokenLookAhead$object;

typedef const struct _jc_gnu_regexp_RETokenLookAhead$vmethods	_jc_gnu_regexp_RETokenLookAhead$vmethods;
typedef const struct _jc_gnu_regexp_RETokenLookAhead$vtable	_jc_gnu_regexp_RETokenLookAhead$vtable;
typedef const struct _jc_gnu_regexp_RETokenLookAhead$vtype	_jc_gnu_regexp_RETokenLookAhead$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenLookAhead$method$_init$104f59eb0896f77f(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_gnu_regexp_REToken$object *, jboolean);

// Virtual methods
extern void _jc_gnu_regexp_RETokenLookAhead$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_java_lang_StringBuffer$object *);
extern jboolean _jc_gnu_regexp_RETokenLookAhead$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenLookAhead$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenLookAhead$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenLookAhead$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_java_lang_StringBuffer$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenLookAhead$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenLookAhead$vmethods	gnu_regexp_RETokenLookAhead;
};

// Vtype
struct _jc_gnu_regexp_RETokenLookAhead$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenLookAhead$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenLookAhead$sub_refs {
	struct _jc_gnu_regexp_REToken$object	*re;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenLookAhead$refs {
    _jc_gnu_regexp_RETokenLookAhead$sub_refs	gnu_regexp_RETokenLookAhead;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenLookAhead$sub_nonrefs {
	jboolean	negative;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenLookAhead$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenLookAhead$sub_nonrefs	gnu_regexp_RETokenLookAhead;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenLookAhead$object {
	_jc_gnu_regexp_RETokenLookAhead$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenLookAhead$vtype	*vtype;
	_jc_gnu_regexp_RETokenLookAhead$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenLookAhead$vtype _jc_gnu_regexp_RETokenLookAhead$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenLookAhead, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenLookAhead$class_object;

#endif	/* _JC_gnu_regexp_RETokenLookAhead_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenLookAhead.h <==
// final class gnu.regexp.RETokenLookAhead

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class ee8e5ce64b7367ac gnu_regexp_RETokenLookAhead
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenLookAhead_H_
#define _JC_gnu_regexp_RETokenLookAhead_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_gnu_regexp_REToken$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenLookAhead$sub_refs	_jc_gnu_regexp_RETokenLookAhead$sub_refs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$sub_nonrefs	_jc_gnu_regexp_RETokenLookAhead$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$refs	_jc_gnu_regexp_RETokenLookAhead$refs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$nonrefs	_jc_gnu_regexp_RETokenLookAhead$nonrefs;
typedef struct _jc_gnu_regexp_RETokenLookAhead$object	_jc_gnu_regexp_RETokenLookAhead$object;

typedef const struct _jc_gnu_regexp_RETokenLookAhead$vmethods	_jc_gnu_regexp_RETokenLookAhead$vmethods;
typedef const struct _jc_gnu_regexp_RETokenLookAhead$vtable	_jc_gnu_regexp_RETokenLookAhead$vtable;
typedef const struct _jc_gnu_regexp_RETokenLookAhead$vtype	_jc_gnu_regexp_RETokenLookAhead$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenLookAhead$method$_init$104f59eb0896f77f(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_gnu_regexp_REToken$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenLookAhead$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenLookAhead$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenLookAhead$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenLookAhead$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenLookAhead$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenLookAhead$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenLookAhead$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenLookAhead$vmethods	gnu_regexp_RETokenLookAhead;
};

// Vtype
struct _jc_gnu_regexp_RETokenLookAhead$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenLookAhead$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenLookAhead$sub_refs {
	struct _jc_gnu_regexp_REToken$object	*re;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenLookAhead$refs {
    _jc_gnu_regexp_RETokenLookAhead$sub_refs	gnu_regexp_RETokenLookAhead;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenLookAhead$sub_nonrefs {
	jboolean	negative;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenLookAhead$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenLookAhead$sub_nonrefs	gnu_regexp_RETokenLookAhead;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenLookAhead$object {
	_jc_gnu_regexp_RETokenLookAhead$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenLookAhead$vtype	*vtype;
	_jc_gnu_regexp_RETokenLookAhead$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenLookAhead$vtype _jc_gnu_regexp_RETokenLookAhead$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenLookAhead, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenLookAhead$class_object;

#endif	/* _JC_gnu_regexp_RETokenLookAhead_H_ */
